Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(293)

Unified Diff: runtime/platform/globals.h

Issue 139043003: - Address warnings about 64-bit to 32-bit conversions. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/platform/globals.h
===================================================================
--- runtime/platform/globals.h (revision 31816)
+++ runtime/platform/globals.h (working copy)
@@ -255,11 +255,6 @@
typedef intptr_t word;
typedef uintptr_t uword;
-#if defined(TARGET_OS_WINDOWS) || defined(TARGET_OS_MACOS)
-// off64_t is not defined on Windows or Mac OS.
-typedef int64_t off64_t;
-#endif
-
// Byte sizes.
const int kWordSize = sizeof(word);
const int kDoubleSize = sizeof(double); // NOLINT
@@ -469,12 +464,12 @@
#if !defined(TEMP_FAILURE_RETRY)
// TEMP_FAILURE_RETRY is defined in unistd.h on some platforms. The
// definition below is copied from Linux and adapted to avoid lint
// errors (type long int changed to int64_t and do/while split on
// separate lines with body in {}s).
#define TEMP_FAILURE_RETRY(expression) \
- ({ int64_t __result; \
+ ({ intptr_t __result; \
do { \
- __result = static_cast<int64_t>(expression); \
+ __result = static_cast<intptr_t>(expression); \
siva 2014/01/16 00:15:59 We probably should not have a static cast here to
Ivan Posva 2014/01/16 05:05:41 You are absolutely right. I did review the current
} while (__result == -1L && errno == EINTR); \
@@ -469,12 +464,12 @@
// TEMP_FAILURE_RETRY is defined in unistd.h on some platforms. The
// definition below is copied from Linux and adapted to avoid lint
-// errors (type long int changed to int64_t and do/while split on
+// errors (type long int changed to intptr_t and do/while split on
// separate lines with body in {}s).
#define TEMP_FAILURE_RETRY(expression) \
__result; })
#endif // !defined(TEMP_FAILURE_RETRY)

Powered by Google App Engine
This is Rietveld 408576698